==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/kivio/plugins/kiviozoomtool/tool_zoom.h <==
/*
 * Kivio - Visual Modelling and Flowcharting
 * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TOOL_ZOOM_H
#define TOOL_ZOOM_H

#include "kivio_mousetool.h"

class KivioView;
class KivioPage;
class KivioCanvas;
class KPopupMenu;

class KRadioAction;
class KAction;

class TQCursor;

class ZoomTool : public Kivio::MouseTool
{
  Q_OBJECT
  TQ_OBJECT
  public:
    ZoomTool(KivioView* parent);
    virtual ~ZoomTool();
  
    virtual bool processEvent(TQEvent* e);
  
    void zoomRect(TQRect);
  
  public slots:
    void zoomActivated();
    void handActivated();
  
    void zoomPlus();
    void zoomMinus();
    void zoomWidth();
    void zoomHeight();
    void zoomPage();
    void zoomSelected();
    void zoomAllobjects();
    
    virtual void setActivated(bool a);
  
  protected:
    void showPopupMenu(const TQPoint&);
  
  signals:
    void operationDone();
  
  private:
    KRadioAction* m_zoomAction;
    KRadioAction* m_panAction;
  
    KPopupMenu* m_pMenu;
  
    KAction* m_pMinus;
    KAction* m_pPlus;
    KAction* m_pZoomWidth;
    KAction* m_pZoomHeight;
    KAction* m_pZoomSelected;
    KAction* m_pZoomPage;
    KAction* m_pZoomAllObjects;
  
    KAction* m_pCurrent;
  
    TQCursor* m_pPlusCursor;
    TQCursor* m_pMinusCursor;
    TQCursor* m_handCursor;
  
    bool m_bDrawRubber;
    bool m_bHandMode;
    bool isHandMousePressed;
    bool m_bLockKeyboard;
    TQPoint mousePos;
};

#endif

==> koffice-trinity-14.0.13.tar.xz: koffice-trinity-14.0.13/kivio/plugins/kiviozoomtool/tool_zoom.h <==
/*
 * Kivio - Visual Modelling and Flowcharting
 * Copyright (C) 2000-2001 theKompany.com & Dave Marotti
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TOOL_ZOOM_H
#define TOOL_ZOOM_H

#include "kivio_mousetool.h"

class KivioView;
class KivioPage;
class KivioCanvas;
class TDEPopupMenu;

class TDERadioAction;
class TDEAction;

class TQCursor;

class ZoomTool : public Kivio::MouseTool
{
  Q_OBJECT
  
  public:
    ZoomTool(KivioView* parent);
    virtual ~ZoomTool();
  
    virtual bool processEvent(TQEvent* e);
  
    void zoomRect(TQRect);
  
  public slots:
    void zoomActivated();
    void handActivated();
  
    void zoomPlus();
    void zoomMinus();
    void zoomWidth();
    void zoomHeight();
    void zoomPage();
    void zoomSelected();
    void zoomAllobjects();
    
    virtual void setActivated(bool a);
  
  protected:
    void showPopupMenu(const TQPoint&);
  
  signals:
    void operationDone();
  
  private:
    TDERadioAction* m_zoomAction;
    TDERadioAction* m_panAction;
  
    TDEPopupMenu* m_pMenu;
  
    TDEAction* m_pMinus;
    TDEAction* m_pPlus;
    TDEAction* m_pZoomWidth;
    TDEAction* m_pZoomHeight;
    TDEAction* m_pZoomSelected;
    TDEAction* m_pZoomPage;
    TDEAction* m_pZoomAllObjects;
  
    TDEAction* m_pCurrent;
  
    TQCursor* m_pPlusCursor;
    TQCursor* m_pMinusCursor;
    TQCursor* m_handCursor;
  
    bool m_bDrawRubber;
    bool m_bHandMode;
    bool isHandMousePressed;
    bool m_bLockKeyboard;
    TQPoint mousePos;
};

#endif
